@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 
 name = 'TracCaptcha'
-version = '0.2'
+version = '0.2.1'
 description = 'pluggable captcha infrastructure for trac with reCAPTCHA included'
 long_description = '''
 TracCaptcha is a trac plugin to embed a captcha in the ticket page in addition 
@@ -34,6 +34,10 @@ of displaying your plugin in all supported pages!
 Changelog
 ******************************
 
+0.2.1 (10.11.2010)
+====================
+- fix "installation" as egg file in Trac plugins folder
+
 0.2 (10.07.2010)
 ====================
 - integration in 3rd party trac plugins: TracDiscussionPlugin and 
@@ -52,9 +56,10 @@ Changelog
  - initial release
 '''
 author = 'Felix Schwarz'
-email = 'felix.schwarz@oss.schwarz.eu'
+author_email = 'felix.schwarz@oss.schwarz.eu'
 url = 'http://www.schwarz.eu/opensource/projects/trac_captcha'
 download_url = 'http://www.schwarz.eu/opensource/projects/%(name)s/download/%(version)s/%(name)s-%(version)s.tar.gz' % dict(name=name, version=version)
-copyright = u'2010 Felix Schwarz'
+# prefix it with '_' so the symbol is not passed to setuptools.setup()
+_copyright = u'2010 Felix Schwarz'
 license='MIT'
 
